/*
############################################################
Empty hook

Adds the "onempty" command which runs the specified command when the
last client disconnects.  E.g. "server,onempty shutdown".

Also calls empty_handler() when the last client in the server
disconnects.
############################################################
*/
var empty_handler = function () { };

var empty_commands = [];

function run_empty_commands() {
	var i;

	for (i in empty_commands)
		mxserver.schedule_command("at +0 " + empty_commands[i]);

	empty_commands.length = 0;
}

function server_empty(slot) {
	var i, status;

	for (i = 0; i < mxserver.max_slots; i++) {
		if (i == slot)
			continue;

		status = mxserver.get_status(i);

		if (status == "Player" || status == "Spectator")
			return false;
	}

	return true;
}

function empty_hook(slot) {
	if (server_empty(slot)) {
		run_empty_commands();

		empty_handler();
	}

	empty_hook_prev(slot);
}

var empty_hook_prev = mxserver.disconnect_handler;
mxserver.disconnect_handler = empty_hook;

function onempty(slot, cmdline) {
        var m, r, i;

        if (cmdline.match(/^\s*onempty\b/) == null)
                return onempty_prev(slot, cmdline);

	if (slot != mxserver.max_slots && mxserver.get_string("rank", slot) != "Admin") {
		mxserver.send(slot, "Permission denied");
		return 1;
	}

        m = cmdline.match(/^\s*onempty\s*(.*)/);

	empty_commands.push(m[1]);

	mxserver.send(slot, "Running '" + m[1] + "' next time server is empty");

	if (server_empty(mxserver.max_slots))
		run_empty_commands();

        return 1;
}

var onempty_prev = mxserver.command_handler;
mxserver.command_handler = onempty;
